@@ -24,7 +24,7 @@ Example
 
 Simple cross-section demo:
 
-.. literalinclude:: ../guiqwt/tests/cross_section.py
+.. literalinclude:: /../guiqwt/tests/cross_section.py
 
 Reference
 ~~~~~~~~~
@@ -43,7 +43,7 @@ import weakref
 
 from guidata.qt.QtGui import (QVBoxLayout, QSizePolicy, QHBoxLayout, QToolBar,
                               QSpacerItem)
-from guidata.qt.QtCore import QSize, QPoint, Qt, SIGNAL
+from guidata.qt.QtCore import QSize, QPointF, Qt
 
 import numpy as np
 
@@ -61,11 +61,6 @@ from guiqwt.styles import CurveParam
 from guiqwt.tools import ExportItemDataTool
 from guiqwt.geometry import translate, rotate, vector_norm, vector_angle
 from guiqwt.image import _scale_tr, INTERP_LINEAR
-from guiqwt.signals import (SIG_MARKER_CHANGED, SIG_PLOT_LABELS_CHANGED,
-                            SIG_ANNOTATION_CHANGED, SIG_AXIS_DIRECTION_CHANGED,
-                            SIG_ITEMS_CHANGED, SIG_ACTIVE_ITEM_CHANGED,
-                            SIG_LUT_CHANGED, SIG_CS_CURVE_CHANGED,
-                            SIG_MASK_CHANGED)
 from guiqwt.plot import PlotManager
 from guiqwt.builder import make
 from guiqwt.baseplot import canvas_to_axes, axes_to_canvas
@@ -74,12 +69,13 @@ from guiqwt.baseplot import canvas_to_axes, axes_to_canvas
 class CrossSectionItem(ErrorBarCurveItem):
     """A Qwt item representing cross section data"""
     __implements__ = (IBasePlotItem,)
-    _inverted = None
+    ORIENTATION = None
     
     def __init__(self, curveparam=None, errorbarparam=None):
         ErrorBarCurveItem.__init__(self, curveparam, errorbarparam)
+        self.setOrientation(self.ORIENTATION)
         self.perimage_mode = True
-        self.autoscale_mode = True
+        self.autoscale_mode = False
         self.apply_lut = False
         self.source = None
         
@@ -101,13 +97,13 @@ class CrossSectionItem(ErrorBarCurveItem):
         
     def clear_data(self):
         self.set_data(np.array([]), np.array([]), None, None)
-        self.plot().emit(SIG_CS_CURVE_CHANGED, self)
+        self.plot().SIG_CS_CURVE_CHANGED.emit(self)
 
     def update_curve_data(self, obj):
         sectx, secty = self.get_cross_section(obj)
         if secty.size == 0 or np.all(np.isnan(secty)):
             sectx, secty = np.array([]), np.array([])
-        if self._inverted:
+        if self.orientation() == Qt.Vertical:
             self.process_curve_data(secty, sectx)
         else:
             self.process_curve_data(sectx, secty)
@@ -127,12 +123,20 @@ class CrossSectionItem(ErrorBarCurveItem):
         if source is None or not plot.isVisible():
             return
         self.update_curve_data(obj)
-        self.plot().emit(SIG_CS_CURVE_CHANGED, self)
+        self.plot().SIG_CS_CURVE_CHANGED.emit(self)
         if not self.autoscale_mode:
             self.update_scale()
-
+            
     def update_scale(self):
-        raise NotImplementedError
+        plot = self.plot()
+        if self.orientation() == Qt.Vertical:
+            axis_id = plot.Y_LEFT
+        else:
+            axis_id = plot.X_BOTTOM
+        source = self.get_source_image()
+        sdiv = source.plot().axisScaleDiv(axis_id)
+        plot.setAxisScale(axis_id, sdiv.lowerBound(), sdiv.upperBound())
+        plot.replot()
 
 
 def get_rectangular_area(obj):
@@ -165,17 +169,17 @@ def get_plot_x_section(obj, apply_lut=False):
     if plot.get_axis_direction("left"):
         yc1 = yc0+1
     else:
-        yc1 = yc0-1
+        yc1 = yc0-3
     try:
         #TODO: eventually add an option to apply interpolation algorithm
-        data = get_image_from_qrect(plot, QPoint(xc0, yc0), QPoint(xc1, yc1),
-                                    apply_lut=apply_lut,
+        data = get_image_from_qrect(plot, QPointF(xc0, yc0), QPointF(xc1, yc1),
+                                    apply_lut=apply_lut, add_images=True,
                                     apply_interpolation=False)
     except (ValueError, ZeroDivisionError, TypeError):
         return np.array([]), np.array([])
     y = data.mean(axis=0)
-    x0, _y0 = canvas_to_axes(obj, QPoint(xc0, yc0))
-    x1, _y1 = canvas_to_axes(obj, QPoint(xc1, yc1))
+    x0, _y0 = canvas_to_axes(obj, QPointF(xc0, yc0))
+    x1, _y1 = canvas_to_axes(obj, QPointF(xc1, yc1))
     x = np.linspace(x0, x1, len(y))
     return x, y
 
@@ -193,14 +197,14 @@ def get_plot_y_section(obj, apply_lut=False):
     xc0, _yc0 = axes_to_canvas(obj, x0, 0)
     xc1 = xc0+1
     try:
-        data = get_image_from_qrect(plot, QPoint(xc0, yc0), QPoint(xc1, yc1),
-                                    apply_lut=apply_lut,
+        data = get_image_from_qrect(plot, QPointF(xc0, yc0), QPointF(xc1, yc1),
+                                    apply_lut=apply_lut, add_images=True,
                                     apply_interpolation=False)
     except (ValueError, ZeroDivisionError, TypeError):
         return np.array([]), np.array([])
     y = data.mean(axis=1)
-    _x0, y0 = canvas_to_axes(obj, QPoint(xc0, yc0))
-    _x1, y1 = canvas_to_axes(obj, QPoint(xc1, yc1))
+    _x0, y0 = canvas_to_axes(obj, QPointF(xc0, yc0))
+    _x1, y1 = canvas_to_axes(obj, QPointF(xc1, yc1))
     x = np.linspace(y0, y1, len(y))
     return x, y
 
@@ -223,7 +227,7 @@ def get_plot_average_x_section(obj, apply_lut=False):
         yc1, yc0 = yc0, yc1
     try:
         data = get_image_from_qrect(obj.plot(),
-                                    QPoint(xc0, yc0), QPoint(xc1, yc1),
+                                    QPointF(xc0, yc0), QPointF(xc1, yc1),
                                     apply_lut=apply_lut,
                                     apply_interpolation=False)
     except (ValueError, ZeroDivisionError, TypeError):
@@ -252,7 +256,7 @@ def get_plot_average_y_section(obj, apply_lut=False):
         xc1, xc0 = xc0, xc1
     try:
         data = get_image_from_qrect(obj.plot(),
-                                    QPoint(xc0, yc0), QPoint(xc1, yc1),
+                                    QPointF(xc0, yc0), QPointF(xc1, yc1),
                                     apply_lut=apply_lut,
                                     apply_interpolation=False)
     except (ValueError, ZeroDivisionError, TypeError):
@@ -266,7 +270,8 @@ def get_plot_average_y_section(obj, apply_lut=False):
 
 class XCrossSectionItem(CrossSectionItem):
     """A Qwt item representing x-axis cross section data"""
-    _inverted = False
+    ORIENTATION = Qt.Horizontal
+
     def get_cross_section(self, obj):
         """Get x-cross section data from source image"""
         source = self.get_source_image()
@@ -285,18 +290,11 @@ class XCrossSectionItem(CrossSectionItem):
                                                    apply_lut=self.apply_lut)
             else:
                 return get_plot_average_x_section(obj, apply_lut=self.apply_lut)
-            
-    def update_scale(self):
-        plot = self.plot()
-        axis_id = plot.X_BOTTOM
-        source = self.get_source_image()
-        sdiv = source.plot().axisScaleDiv(axis_id)
-        plot.setAxisScale(axis_id, sdiv.lowerBound(), sdiv.upperBound())
-        plot.replot()
 
 class YCrossSectionItem(CrossSectionItem):
     """A Qwt item representing y-axis cross section data"""
-    _inverted = True
+    ORIENTATION = Qt.Vertical
+
     def get_cross_section(self, obj):
         """Get y-cross section data from source image"""
         source = self.get_source_image()
@@ -315,14 +313,6 @@ class YCrossSectionItem(CrossSectionItem):
                                                    apply_lut=self.apply_lut)
             else:
                 return get_plot_average_y_section(obj, apply_lut=self.apply_lut)
-            
-    def update_scale(self):
-        plot = self.plot()
-        axis_id = plot.Y_LEFT
-        source = self.get_source_image()
-        sdiv = source.plot().axisScaleDiv(axis_id)
-        plot.setAxisScale(axis_id, sdiv.lowerBound(), sdiv.upperBound())
-        plot.replot()
 
 
 LUT_AXIS_TITLE = _("LUT scale")+(" (0-%d)" % LUT_MAX)
@@ -336,16 +326,16 @@ class CrossSectionPlot(CurvePlot):
     CS_AXIS = None
     Z_AXIS = None
     Z_MAX_MAJOR = 5
-    CURVETYPE = None
     SHADE = .2
     def __init__(self, parent=None):
         super(CrossSectionPlot, self).__init__(parent=parent, title="",
                                                section="cross_section")
         self.perimage_mode = True
-        self.autoscale_mode = True
+        self.autoscale_mode = False
         self.autorefresh_mode = True
         self.apply_lut = False
         self.single_source = False
+        self.lockscales = True
         
         self.last_obj = None
         self.known_items = {}
@@ -368,7 +358,6 @@ class CrossSectionPlot(CurvePlot):
 
     def set_curve_style(self, section, option):
         self.curveparam.read_config(CONF, section, option)
-        self.curveparam.curvetype = self.CURVETYPE
         self.curveparam.label = self.CURVE_LABEL
         
     def connect_plot(self, plot):
@@ -376,14 +365,15 @@ class CrossSectionPlot(CurvePlot):
             # Connecting only to image plot widgets (allow mixing image and 
             # curve widgets for the same plot manager -- e.g. in pyplot)
             return
-        self.connect(plot, SIG_ITEMS_CHANGED, self.items_changed)
-        self.connect(plot, SIG_LUT_CHANGED, self.lut_changed)
-        self.connect(plot, SIG_MASK_CHANGED, lambda item: self.update_plot())
-        self.connect(plot, SIG_ACTIVE_ITEM_CHANGED, self.active_item_changed)
-        self.connect(plot, SIG_MARKER_CHANGED, self.marker_changed)
-        self.connect(plot, SIG_ANNOTATION_CHANGED, self.shape_changed)
-        self.connect(plot, SIG_PLOT_LABELS_CHANGED, self.plot_labels_changed)
-        self.connect(plot, SIG_AXIS_DIRECTION_CHANGED, self.axis_dir_changed)
+        plot.SIG_ITEMS_CHANGED.connect(self.items_changed)
+        plot.SIG_LUT_CHANGED.connect(self.lut_changed)
+        plot.SIG_MASK_CHANGED.connect(lambda item: self.update_plot())
+        plot.SIG_ACTIVE_ITEM_CHANGED.connect(self.active_item_changed)
+        plot.SIG_MARKER_CHANGED.connect(self.marker_changed)
+        plot.SIG_ANNOTATION_CHANGED.connect(self.shape_changed)
+        plot.SIG_PLOT_LABELS_CHANGED.connect(self.plot_labels_changed)
+        plot.SIG_AXIS_DIRECTION_CHANGED.connect(self.axis_dir_changed)
+        plot.SIG_PLOT_AXIS_CHANGED.connect(self.plot_axis_changed)
         self.plot_labels_changed(plot)
         for axis_id in plot.AXIS_IDS:
             self.axis_dir_changed(plot, axis_id)
@@ -431,6 +421,12 @@ class CrossSectionPlot(CurvePlot):
                                    #  cross section curve is now empty)
                 self.del_item(curve)
         
+        # Update plot only to show/hide cross section curves according to 
+        # the associated image item visibility state (hence `refresh=False`)
+        self.update_plot(refresh=False)
+        
+        self.plot_axis_changed(plot)
+
         if not new_sources:
             self.replot()
             return
@@ -452,6 +448,13 @@ class CrossSectionPlot(CurvePlot):
     def axis_dir_changed(self, plot, axis_id):
         """An axis direction has changed"""
         raise NotImplementedError
+
+    def plot_axis_changed(self, plot):
+        """Plot was just zoomed/panned"""
+        if self.lockscales:
+            self.do_autoscale(replot=False, axis_id=self.Z_AXIS)
+            vmin, vmax = plot.get_axis_limits(self.CS_AXIS)
+            self.set_axis_limits(self.CS_AXIS, vmin, vmax)
         
     def marker_changed(self, marker):
         self.update_plot(marker)
@@ -493,8 +496,9 @@ class CrossSectionPlot(CurvePlot):
             return
         if self.label.isVisible():
             self.label.hide()
-        for index, (_item, curve) in enumerate(iter(list(self.known_items.items()))):
-            if not self.perimage_mode and index > 0:
+        items = list(self.known_items.items())
+        for index, (item, curve) in enumerate(iter(items)):
+            if (not self.perimage_mode and index > 0) or not item.isVisible():
                 curve.hide()
             else:
                 curve.show()
@@ -505,11 +509,8 @@ class CrossSectionPlot(CurvePlot):
                     curve.update_item(obj)
         if self.autoscale_mode:
             self.do_autoscale(replot=True)
-        if self.apply_lut:
-            self.set_axis_title(self.Z_AXIS, LUT_AXIS_TITLE)
-            self.set_axis_color(self.Z_AXIS, "red")
-        else:
-            self.plot_labels_changed(obj.plot())
+        elif self.lockscales:
+            self.do_autoscale(replot=True, axis_id=self.Z_AXIS)
         
     def toggle_perimage_mode(self, state):
         self.perimage_mode = state
@@ -527,6 +528,19 @@ class CrossSectionPlot(CurvePlot):
     def toggle_apply_lut(self, state):
         self.apply_lut = state
         self.update_plot()
+        if self.apply_lut:
+            self.set_axis_title(self.Z_AXIS, LUT_AXIS_TITLE)
+            self.set_axis_color(self.Z_AXIS, "red")
+        else:
+            obj = self.get_last_obj()
+            if obj is not None and obj.plot() is not None:
+                self.plot_labels_changed(obj.plot())
+    
+    def toggle_lockscales(self, state):
+        self.lockscales = state
+        obj = self.get_last_obj()
+        if obj is not None and obj.plot() is not None:
+            self.plot_axis_changed(obj.plot())
         
     def lut_changed(self, plot):
         if self.apply_lut:
@@ -536,7 +550,6 @@ class CrossSectionPlot(CurvePlot):
 class HorizontalCrossSectionPlot(CrossSectionPlot):
     CS_AXIS = CurvePlot.X_BOTTOM
     Z_AXIS = CurvePlot.Y_LEFT
-    CURVETYPE = "Yfx"
     def plot_labels_changed(self, plot):
         """Plot labels have changed"""
         self.set_axis_title("left", plot.get_axis_title("right"))       
@@ -554,7 +567,6 @@ class VerticalCrossSectionPlot(CrossSectionPlot):
     CS_AXIS = CurvePlot.Y_LEFT
     Z_AXIS = CurvePlot.X_BOTTOM
     Z_MAX_MAJOR = 3
-    CURVETYPE = "Xfy"
     def plot_labels_changed(self, plot):
         """Plot labels have changed"""
         self.set_axis_title("bottom", plot.get_axis_title("right"))       
@@ -603,13 +615,13 @@ class CrossSectionWidget(PanelWidget):
         self.autoscale_ac = None
         self.refresh_ac = None
         self.autorefresh_ac = None
+        self.lockscales_ac = None
         
         self.manager = None # manager for the associated image plot
         
         self.local_manager = PlotManager(self)
         self.cs_plot = self.CrossSectionPlotKlass(parent)
-        self.connect(self.cs_plot, SIG_CS_CURVE_CHANGED,
-                     self.cs_curve_has_changed)
+        self.cs_plot.SIG_CS_CURVE_CHANGED.connect(self.cs_curve_has_changed)
         self.export_tool = None
         self.setup_plot()
         
@@ -618,12 +630,14 @@ class CrossSectionWidget(PanelWidget):
         
         self.setup_widget()
         
-    def set_options(self, autoscale=None, autorefresh=None):
+    def set_options(self, autoscale=None, autorefresh=None, lockscales=None):
         assert self.manager is not None, "Panel '%s' must be registered to plot manager before changing options" % self.PANEL_ID
         if autoscale is not None:
             self.autoscale_ac.setChecked(autoscale)
         if autorefresh is not None:
             self.autorefresh_ac.setChecked(autorefresh)
+        if lockscales is not None:
+            self.lockscales_ac.setChecked(lockscales)
 
     def setup_plot(self):
         # Configure the local manager
@@ -661,9 +675,15 @@ class CrossSectionWidget(PanelWidget):
         
     def setup_actions(self):
         self.export_ac = self.export_tool.action
+        self.lockscales_ac = create_action(self, _("Lock scales"),
+                                   icon=get_icon('axes.png'),
+                                   toggled=self.cs_plot.toggle_lockscales,
+                                   tip=_("Lock scales to main plot axes"))
+        self.lockscales_ac.setChecked(self.cs_plot.lockscales)
         self.autoscale_ac = create_action(self, _("Auto-scale"),
                                    icon=get_icon('csautoscale.png'),
                                    toggled=self.cs_plot.toggle_autoscale)
+        self.autoscale_ac.toggled.connect(self.lockscales_ac.setDisabled)
         self.autoscale_ac.setChecked(self.cs_plot.autoscale_mode)
         self.refresh_ac = create_action(self, _("Refresh"),
                                    icon=get_icon('refresh.png'),
@@ -674,8 +694,9 @@ class CrossSectionWidget(PanelWidget):
         self.autorefresh_ac.setChecked(self.cs_plot.autorefresh_mode)
         
     def add_actions_to_toolbar(self):
-        add_actions(self.toolbar, (self.export_ac, self.autoscale_ac,
-                                   None, self.refresh_ac, self.autorefresh_ac))
+        add_actions(self.toolbar, (self.export_ac, None, self.autoscale_ac,
+                                   self.lockscales_ac, None,
+                                   self.refresh_ac, self.autorefresh_ac,))
         
     def register_shape(self, shape, final, refresh=True):
         plot = self.get_plot()
@@ -713,12 +734,14 @@ class XCrossSection(CrossSectionWidget):
         self.applylut_ac = None
         
     def set_options(self, autoscale=None, autorefresh=None,
-                    peritem=None, applylut=None):
+                    peritem=None, applylut=None, lockscales=None):
         assert self.manager is not None, "Panel '%s' must be registered to plot manager before changing options" % self.PANEL_ID
         if autoscale is not None:
             self.autoscale_ac.setChecked(autoscale)
         if autorefresh is not None:
             self.autorefresh_ac.setChecked(autorefresh)
+        if lockscales is not None:
+            self.lockscales_ac.setChecked(lockscales)
         if peritem is not None:
             self.peritem_ac.setChecked(peritem)
         if applylut is not None:
@@ -728,24 +751,22 @@ class XCrossSection(CrossSectionWidget):
         other = self.manager.get_panel(self.OTHER_PANEL_ID)
         if other is None:
             add_actions(self.toolbar,
-                        (self.peritem_ac, self.applylut_ac, None,
-                         self.export_ac, self.autoscale_ac,
-                         self.refresh_ac, self.autorefresh_ac))
+                        (self.peritem_ac, self.applylut_ac, 
+                         None, self.export_ac, 
+                         None, self.autoscale_ac, self.lockscales_ac,
+                         None, self.refresh_ac, self.autorefresh_ac))
         else:
             add_actions(self.toolbar,
-                        (other.peritem_ac, other.applylut_ac, None,
-                         self.export_ac, other.autoscale_ac,
-                         other.refresh_ac, other.autorefresh_ac))
-            self.connect(other.peritem_ac, SIGNAL("toggled(bool)"),
-                         self.cs_plot.toggle_perimage_mode)
-            self.connect(other.applylut_ac, SIGNAL("toggled(bool)"),
-                         self.cs_plot.toggle_apply_lut)
-            self.connect(other.autoscale_ac, SIGNAL("toggled(bool)"),
-                         self.cs_plot.toggle_autoscale)
-            self.connect(other.refresh_ac, SIGNAL("triggered()"),
-                         lambda: self.cs_plot.update_plot())
-            self.connect(other.autorefresh_ac, SIGNAL("toggled(bool)"),
-                         self.cs_plot.toggle_autorefresh)
+                        (other.peritem_ac, other.applylut_ac, 
+                         None, self.export_ac, 
+                         None, other.autoscale_ac, other.lockscales_ac,
+                         None, other.refresh_ac, other.autorefresh_ac))
+            other.peritem_ac.toggled.connect(self.cs_plot.toggle_perimage_mode)
+            other.applylut_ac.toggled.connect(self.cs_plot.toggle_apply_lut)
+            other.autoscale_ac.toggled.connect(self.cs_plot.toggle_autoscale)
+            other.refresh_ac.triggered.connect(lambda: self.cs_plot.update_plot())
+            other.autorefresh_ac.toggled.connect(self.cs_plot.toggle_autorefresh)
+            other.lockscales_ac.toggled.connect(self.cs_plot.toggle_lockscales)
         
     def closeEvent(self, event):
         self.hide()
@@ -921,3 +942,7 @@ class ObliqueCrossSection(CrossSectionWidget):
     CrossSectionPlotKlass = ObliqueCrossSectionPlot
     PANEL_ICON = "csection_oblique.png"
 
+    def setup_actions(self):
+        super(ObliqueCrossSection, self).setup_actions()
+        self.lockscales_ac.setChecked(False)
+        self.autoscale_ac.setChecked(True)
