@@ -13,10 +13,13 @@ The `debug` module contains some debugging functions (mostly dumping attributes
 of Qt Objects).
 """
 
-from StringIO import StringIO
+from __future__ import print_function
+
 from guidata.qt.QtGui import QImage, QInputEvent
 from guidata.qt.QtCore import Qt, QEvent
 
+from guidata.py3compat import io
+
 def buttons_to_str(buttons):
     """Conversion des flags Qt en chaine"""
     string = ""
@@ -29,7 +32,7 @@ def buttons_to_str(buttons):
     return string
 
 
-def evt_type_to_str( type ):
+def evt_type_to_str(type):
     """Représentation textuelle d'un type d'événement (debug)"""
     if type == QEvent.MouseButtonPress:
         return "Mpress"
@@ -57,9 +60,9 @@ def print_event(evt):
             buttons = 0
         string += buttons_to_str(buttons)
     if string:
-        print string
+        print(string)
     else:
-        print evt
+        print(evt)
 
 
 def qimage_format( fmt ):
@@ -71,10 +74,10 @@ def qimage_format( fmt ):
     return str(fmt)
     
 def qimage_to_str( img, indent="" ):
-    fd = StringIO()
-    print >>fd, indent, img
+    fd = io.StringIO()
+    print(indent, img, file=fd)
     indent += "  "
-    print >>fd, indent, "Size:", img.width(), "x", img.height()
-    print >>fd, indent, "Depth:", img.depth()
-    print >>fd, indent, "Format", qimage_format(img.format())
+    print(indent, "Size:", img.width(), "x", img.height(), file=fd)
+    print(indent, "Depth:", img.depth(), file=fd)
+    print(indent, "Format", qimage_format(img.format()), file=fd)
     return fd.getvalue()
