@@ -19,15 +19,13 @@ The `event` module handles event management (states, event filter, ...).
 from __future__ import print_function
 
 import weakref
-from guidata.qt.QtCore import QEvent, Qt, QObject, QPoint
+from guidata.qt.QtCore import QEvent, Qt, QObject, QPointF, Signal
 from guidata.qt.QtGui import QKeySequence
 
 CursorShape = type(Qt.ArrowCursor)
 
 from guiqwt.config import CONF
 from guiqwt.debug import evt_type_to_str, buttons_to_str
-from guiqwt.signals import (SIG_CLICK_EVENT, SIG_START_TRACKING, SIG_END_RECT,
-                            SIG_STOP_NOT_MOVING, SIG_STOP_MOVING, SIG_MOVE)
 
 
 # Sélection d'événements  ---------
@@ -282,11 +280,11 @@ class DragHandler(QObject):
         rct = filter.plot.contentsRect()
         dx = (pos.x(), self.last.x(), self.start.x(), rct.width())
         dy = (pos.y(), self.last.y(), self.start.y(), rct.height())
-        self.last = QPoint(pos)
+        self.last = QPointF(pos)
         return dx, dy
 
     def start_tracking(self, _filter, event):
-        self.start = self.last = QPoint(event.pos())
+        self.start = self.last = QPointF(event.pos())
 
     def start_moving(self, filter, event):
         return self.move(filter, event)
@@ -309,6 +307,10 @@ class ClickHandler(QObject):
     """Classe de base pour les gestionnaires d'événements du type
     click - release
     """
+    
+    #: Signal emitted by ClickHandler on mouse click
+    SIG_CLICK_EVENT = Signal("PyQt_PyObject", "QEvent")
+    
     def __init__(self, filter, btn, mods=Qt.NoModifier, start_state=0):
         super(ClickHandler, self).__init__()
         self.state0 = filter.add_event(start_state,
@@ -318,7 +320,7 @@ class ClickHandler(QObject):
                          self.click, start_state)
 
     def click(self, filter, event):
-        self.emit(SIG_CLICK_EVENT, filter, event)
+        self.SIG_CLICK_EVENT.emit(filter, event)
 
 
 class PanHandler(DragHandler):
@@ -343,18 +345,31 @@ class MenuHandler(ClickHandler):
 
 
 class QtDragHandler(DragHandler):
+
+    #: Signal emitted by QtDragHandler when starting tracking
+    SIG_START_TRACKING = Signal("PyQt_PyObject", "QEvent")
+    
+    #: Signal emitted by QtDragHandler when stopping tracking and not moving
+    SIG_STOP_NOT_MOVING = Signal("PyQt_PyObject", "QEvent")
+    
+    #: Signal emitted by QtDragHandler when stopping tracking and moving
+    SIG_STOP_MOVING = Signal("PyQt_PyObject", "QEvent")
+    
+    #: Signal emitted by QtDragHandler when moving
+    SIG_MOVE = Signal("PyQt_PyObject", "QEvent")
+
     def start_tracking(self, filter, event):
         DragHandler.start_tracking(self, filter, event)
-        self.emit(SIG_START_TRACKING, filter, event)
+        self.SIG_START_TRACKING.emit(filter, event)
 
     def stop_notmoving(self, filter, event):
-        self.emit(SIG_STOP_NOT_MOVING, filter, event)
+        self.SIG_STOP_NOT_MOVING.emit(filter, event)
 
     def stop_moving(self, filter, event):
-        self.emit(SIG_STOP_MOVING, filter, event)
+        self.SIG_STOP_MOVING.emit(filter, event)
 
     def move(self, filter, event):
-        self.emit(SIG_MOVE, filter, event)
+        self.SIG_MOVE.emit(filter, event)
 
 
 class AutoZoomHandler(ClickHandler):
@@ -383,8 +398,8 @@ class UndoMoveObject(object):
     
     def compute_positions(self):
         from guiqwt.baseplot import axes_to_canvas
-        pos1 = QPoint(*axes_to_canvas(self.obj, *self.coords1))
-        pos2 = QPoint(*axes_to_canvas(self.obj, *self.coords2))
+        pos1 = QPointF(*axes_to_canvas(self.obj, *self.coords1))
+        pos2 = QPointF(*axes_to_canvas(self.obj, *self.coords2))
         return pos1, pos2
     
     def undo(self):
@@ -481,7 +496,7 @@ class ObjectHandler(object):
         self.active = None
         self.handle = None
         self.first_pos = pos = event.pos()
-        self.last_pos = QPoint(pos)
+        self.last_pos = QPointF(pos)
         selected = plot.get_active_item()
         distance = CONF.get("plot", "selection/distance", 6)
 
@@ -569,7 +584,7 @@ class ObjectHandler(object):
             self.active.move_local_point_to(self.handle, event.pos(), ctrl)
             self.undo_action = UndoMovePoint(self.active, self.first_pos,
                                              event.pos(), self.handle, ctrl)
-        self.last_pos = QPoint(event.pos())
+        self.last_pos = QPointF(event.pos())
         filter.plot.replot()
         
     def stop_tracking(self, filter, event):
@@ -581,6 +596,10 @@ class ObjectHandler(object):
 
 
 class RectangularSelectionHandler(DragHandler):
+
+    #: Signal emitted by RectangularSelectionHandler when ending selection
+    SIG_END_RECT = Signal("PyQt_PyObject", "QPointF", "QPointF")
+    
     def __init__(self, filter, btn, mods=Qt.NoModifier, start_state=0):
         super(RectangularSelectionHandler, self).__init__(filter, btn, mods,
                                                           start_state)
@@ -595,13 +614,13 @@ class RectangularSelectionHandler(DragHandler):
         self.avoid_null_shape = avoid_null_shape
 
     def start_tracking(self, filter, event):
-        self.start = self.last = QPoint(event.pos())
+        self.start = self.last = QPointF(event.pos())
 
     def start_moving(self, filter, event):
         self.shape.attach(filter.plot)
         self.shape.setZ(filter.plot.get_max_z()+1)
         if self.avoid_null_shape:
-            self.start -= QPoint(1, 1)
+            self.start -= QPointF(1, 1)
         self.shape.move_local_point_to(self.shape_h0, self.start)
         self.shape.move_local_point_to(self.shape_h1, event.pos())
         self.start_moving_action(filter, event)
@@ -630,7 +649,7 @@ class RectangularSelectionHandler(DragHandler):
         
     def stop_moving_action(self, filter, event):
         """Les classes derivees peuvent surcharger cette methode"""
-        self.emit(SIG_END_RECT, filter, self.start, event.pos())
+        self.SIG_END_RECT.emit(filter, self.start, event.pos())
 
 
 class ZoomRectHandler(RectangularSelectionHandler):
