@@ -198,10 +198,10 @@ def _imread_pil(filename, to_grayscale=False):
     if to_grayscale and img.mode in ("RGB", "RGBA", "RGBX"):
         # Converting to grayscale
         img = img.convert("L")
+    elif "A" in img.mode or (img.mode == "P" and "transparency" in img.info):
+        img = img.convert("RGBA")
     elif img.mode == "P":
         img = img.convert("RGB")
-    elif "A" in img.mode:
-        img = img.convert("RGBA")
     try:
         dtype, extra = DTYPES[img.mode]
     except KeyError:
@@ -218,9 +218,18 @@ def _imwrite_pil(filename, arr):
     """Write `arr` NumPy array to `filename` using PIL"""
     import PIL.Image
     import PIL.TiffImagePlugin # py2exe
-    for mode, (dtype_str, _extra) in list(DTYPES.items()):
+    for mode, (dtype_str, extra) in list(DTYPES.items()):
         if dtype_str == arr.dtype.str:
-            break
+            if extra is None:  # mode for grayscale images
+                if len(arr.shape[2:]) > 0:
+                    continue  # not suitable for RGB(A) images
+                else:
+                    break  # this is it!
+            else:  # mode for RGB(A) images
+                if len(arr.shape[2:]) == 0:
+                    continue  # not suitable for grayscale images
+                elif arr.shape[-1] == extra:
+                    break  # this is it!
     else:
         raise RuntimeError("Cannot determine PIL data type")
     img = PIL.Image.fromarray(arr, mode)
@@ -236,13 +245,23 @@ def _import_dcm():
     import logging
     logger = logging.getLogger("pydicom")
     logger.setLevel(logging.CRITICAL)
-    import dicom  # analysis:ignore
+    try:
+        # pydicom 1.0
+        from pydicom import dicomio  # analysis:ignore
+    except ImportError:
+        # pydicom 0.9
+        import dicom as dicomio  # analysis:ignore
     logger.setLevel(logging.WARNING)
 
 def _imread_dcm(filename):
     """Open DICOM image with pydicom and return a NumPy array"""
-    import dicom
-    dcm = dicom.ReadFile(filename)
+    try:
+        # pydicom 1.0
+        from pydicom import dicomio
+    except ImportError:
+        # pydicom 0.9
+        import dicom as dicomio
+    dcm = dicomio.read_file(filename, force=True)
     # **********************************************************************
     # The following is necessary until pydicom numpy support is improved:
     # (after that, a simple: 'arr = dcm.PixelArray' will work the same)
@@ -493,7 +512,7 @@ def save_items(writer, items):
         basename = item_name_from_object(item)
         count = counts[basename] = counts.setdefault(basename, 0) + 1
         name = '%s_%03d' % (basename, count)
-        names.append(name)
+        names.append(name.encode('utf-8'))
         return name
     for item in items:
         with writer.group(_get_name(item)):
@@ -509,7 +528,7 @@ def load_items(reader):
     items = []
     for name in names:
         klass_name = re.match(r'([A-Z]+[A-Za-z0-9\_]*)\_([0-9]*)',
-                              name).groups()[0]
+                              name.decode()).groups()[0]
         klass = item_class_from_name(klass_name)
         item = klass()
         with reader.group(name):
