@@ -47,7 +47,7 @@ Reference
 """
 
 from guidata.qt.QtGui import QPen, QColor, QTextDocument
-from guidata.qt.QtCore import QRectF
+from guidata.qt.QtCore import QRectF, QPointF
 
 from guidata.utils import assert_interfaces_valid, update_dataset
 from guidata.py3compat import to_text_string
@@ -58,7 +58,6 @@ from guiqwt.config import CONF, _
 from guiqwt.curve import CurveItem
 from guiqwt.interfaces import IBasePlotItem, IShapeItemType, ISerializableType
 from guiqwt.styles import LabelParam
-from guiqwt.signals import SIG_ITEM_MOVED
 
 
 ANCHORS = {
@@ -226,8 +225,11 @@ class AbstractLabelItem(QwtPlotItem):
     def click_inside(self, locx, locy):
         return 2.0, 1, True, None
 
-    def get_item_parameters(self, itemparams):
+    def update_item_parameters(self):
         self.labelparam.update_param(self)
+
+    def get_item_parameters(self, itemparams):
+        self.update_item_parameters()
         itemparams.add("LabelParam", self, self.labelparam)
     
     def set_item_parameters(self, itemparams):
@@ -267,7 +269,7 @@ class AbstractLabelItem(QwtPlotItem):
             ly1 = plot.invTransform(self.yAxis(), cy)
             self.G = lx1, ly1
             self.labelparam.xg, self.labelparam.yg = lx1, ly1
-            plot.emit(SIG_ITEM_MOVED, self, lx0, ly0, lx1, ly1)
+            plot.SIG_ITEM_MOVED.emit(self, lx0, ly0, lx1, ly1)
         
     def move_with_selection(self, delta_x, delta_y):
         """
@@ -344,7 +346,7 @@ class LabelItem(AbstractLabelItem):
         x, y = self.get_top_left(xMap, yMap, canvasRect)
         x0, y0 = self.get_origin(xMap, yMap, canvasRect)
         painter.save()
-        self.marker.draw(painter, x0, y0)
+        self.marker.drawSymbols(painter, [QPointF(x0, y0)])
         painter.restore()
         sz = self.text.size()
         self.draw_frame(painter, x, y, sz.width(), sz.height())
@@ -426,7 +428,8 @@ class LegendBoxItem(AbstractLabelItem):
         y0 = y+LEGEND_SPACEV
         x0 = x+LEGEND_SPACEH
         for text, ipen, ibrush, isymbol in items:
-            isymbol.draw(painter, x0+LEGEND_WIDTH/2, y0+height/2)
+            isymbol.drawSymbols(painter,
+                                [QPointF(x0+LEGEND_WIDTH/2, y0+height/2)])
             painter.save()
             painter.setPen(ipen)
             painter.setBrush(ibrush)
@@ -451,8 +454,11 @@ class LegendBoxItem(AbstractLabelItem):
                 return 1000.0, None, False, items[line]
         return 2.0, 1, True, None
 
-    def get_item_parameters(self, itemparams):
+    def update_item_parameters(self):
         self.labelparam.update_param(self)
+
+    def get_item_parameters(self, itemparams):
+        self.update_item_parameters()
         itemparams.add("LegendParam", self, self.labelparam)
     
     def set_item_parameters(self, itemparams):
