@@ -9,9 +9,10 @@
 guiqwt.panels
 -------------
 
-The `panels` module provides :py:class:`guiqwt.curve.PanelWidget` (the `panel` 
-widget class from which all panels must derived) and identifiers for each kind 
-of panel:
+The `panels` module provides :py:class:`guiqwt.panels.PanelWidget` (the 
+`panel` widget class from which all panels must derived from) and identifiers 
+for each kind of panel:
+
     * :py:data:`guiqwt.panels.ID_ITEMLIST`: ID of the `item list` panel
     * :py:data:`guiqwt.panels.ID_CONTRAST`: ID of the `contrast 
       adjustment` panel
@@ -36,29 +37,27 @@ of panel:
         Module providing the `plot tools`
 """
 
+from guidata.qt.QtCore import Signal
 from guidata.qtwidgets import DockableWidget
 
-# Local imports
-from guiqwt.signals import SIG_VISIBILITY_CHANGED
-
 
 #===============================================================================
 # Panel IDs
 #===============================================================================
 
-# Item list panel
+#: Item list panel
 ID_ITEMLIST = "itemlist"
 
-# Contrast adjustment panel
+#: Contrast adjustment panel
 ID_CONTRAST = "contrast"
 
-# X-cross section panel
+#: X-cross section panel
 ID_XCS = "x_cross_section"
 
-# Y-cross section panel
+#: Y-cross section panel
 ID_YCS = "y_cross_section"
 
-# Oblique averaged cross section panel
+#: Oblique averaged cross section panel
 ID_OCS = "oblique_cross_section"
 
 
@@ -66,9 +65,14 @@ ID_OCS = "oblique_cross_section"
 # Base Panel Widget class
 #===============================================================================
 class PanelWidget(DockableWidget):
+    """Panel Widget base class"""
+
     PANEL_ID = None # string
     PANEL_TITLE = None # string
     PANEL_ICON = None # string
+
+    #: Signal emitted by PanelWidget when its visibility has changed (arg: bool)
+    SIG_VISIBILITY_CHANGED = Signal(bool)
     
     def __init__(self, parent=None):
         super(PanelWidget, self).__init__(parent)
@@ -82,16 +86,16 @@ class PanelWidget(DockableWidget):
     def showEvent(self, event):
         DockableWidget.showEvent(self, event)
         if self.dockwidget is None:
-            self.emit(SIG_VISIBILITY_CHANGED, True)
+            self.SIG_VISIBILITY_CHANGED.emit(True)
         
     def hideEvent(self, event):
         DockableWidget.hideEvent(self, event)
         if self.dockwidget is None:
-            self.emit(SIG_VISIBILITY_CHANGED, False)
+            self.SIG_VISIBILITY_CHANGED.emit(False)
         
     def visibility_changed(self, enable):
         """DockWidget visibility has changed"""
         DockableWidget.visibility_changed(self, enable)
         # For compatibility with the guiqwt.panels.PanelWidget interface:
-        self.emit(SIG_VISIBILITY_CHANGED, self._isvisible)
+        self.SIG_VISIBILITY_CHANGED.emit(self._isvisible)
 
