@@ -104,7 +104,7 @@ import numpy as np
 
 from guidata.qt.QtGui import (QPen, QBrush, QColor, QFont, QFontDialog,
                               QTransform)
-from guidata.qt.QtCore import Qt, QSize, QPointF
+from guidata.qt.QtCore import Qt, QSizeF, QPointF
 
 from guidata.dataset.datatypes import (DataSet, ObjectItem, BeginGroup,
                                        EndGroup, Obj, DataSetGroup,
@@ -122,7 +122,6 @@ from guidata.py3compat import to_text_string
 from guiqwt.transitional import QwtPlot, QwtPlotCurve, QwtSymbol, QwtPlotMarker
 from guiqwt.config import _
 from guiqwt.colormap import get_colormap_list, build_icon_from_cmap_name
-from guiqwt.signals import SIG_ITEMS_CHANGED
 
 class ItemParameters(object):
     """Class handling QwtPlotItem-like parameters"""
@@ -168,19 +167,26 @@ class ItemParameters(object):
         return deepcopy(self.paramdict.get(key))
     
     def update(self, plot):
+        #XXX: removed the following workaround as the associated bug can't be 
+        # reproduced anymore with guiqwt 3. However, keeping the workaround 
+        # here (commented) as it could become useful eventually.
+        #-----
         #FIXME: without the following workaround, ImagePlot object aspect ratio
         # is changed when pressing button "Apply"
         # (see also guiqwt.image.ImagePlot.edit_axis_parameters)
-        from guiqwt.image import ImagePlot
-        if isinstance(plot, ImagePlot):
-            ratio = plot.get_current_aspect_ratio()
+#        from guiqwt.image import ImagePlot
+#        if isinstance(plot, ImagePlot):
+#            ratio = plot.get_current_aspect_ratio()
+        #-----
         for item in self.items:
             item.set_item_parameters(self)
         plot.replot()
-        if isinstance(plot, ImagePlot):
-            plot.set_aspect_ratio(ratio=ratio)
-            plot.replot()
-        plot.emit(SIG_ITEMS_CHANGED, plot)
+        #-----
+#        if isinstance(plot, ImagePlot):
+#            plot.set_aspect_ratio(ratio=ratio)
+#            plot.replot()
+        #-----
+        plot.SIG_ITEMS_CHANGED.emit(plot)
     
     def edit(self, plot, title, icon):
         paramdict = self.paramdict.copy()
@@ -216,7 +222,7 @@ MARKERS = {
           "o": QwtSymbol.Ellipse,
           "*": QwtSymbol.Star1,
           ".": QwtSymbol(QwtSymbol.Ellipse, QBrush(Qt.black),
-                          QPen(Qt.black), QSize(3, 3)),
+                          QPen(Qt.black), QSizeF(3, 3)),
           "x": QwtSymbol.XCross,
           "s": QwtSymbol.Rect,
           "d": QwtSymbol.Diamond,
@@ -299,8 +305,6 @@ CURVESTYLE_CHOICES = [("Lines", _("Lines"), "lines.png"),
                       ("Dots", _("Dots"), "dots.png"),
                       ("NoCurve", _("No curve"), "none.png")
                       ]
-CURVETYPE_CHOICES = [("Yfx", _("Draws y as a function of x"), "yfx.png"),
-                     ("Xfy", _("Draws x as a function of y"), "xfy.png")]
 
 BRUSHSTYLE_CHOICES = [
     ("NoBrush", _("No brush pattern"), "nobrush.png"),
@@ -333,7 +337,6 @@ MARKERSTYLE_CHOICES = [("NoLine", _("None"), "none.png"),
 
 MARKER_NAME = build_reverse_map(MARKER_CHOICES, QwtSymbol)
 CURVESTYLE_NAME = build_reverse_map(CURVESTYLE_CHOICES, QwtPlotCurve)
-CURVETYPE_NAME = build_reverse_map(CURVETYPE_CHOICES, QwtPlotCurve)
 LINESTYLE_NAME = build_reverse_map(LINESTYLE_CHOICES, Qt)
 BRUSHSTYLE_NAME = build_reverse_map(BRUSHSTYLE_CHOICES, Qt)
 MARKERSTYLE_NAME = build_reverse_map(MARKERSTYLE_CHOICES, QwtPlotMarker)
@@ -408,7 +411,7 @@ class SymbolParam(DataSet):
         color.setAlphaF(self.alpha)
         marker = QwtSymbol(marker_type, QBrush(color),
                            QPen(QColor(self.edgecolor)),
-                           QSize(self.size, self.size))
+                           QSizeF(self.size, self.size))
         return marker
     
     def update_symbol(self, obj):
@@ -562,25 +565,29 @@ class GridParam(DataSet):
     def update_param(self, grid):
         plot = grid.plot()
         if plot is not None:
-            self.background = str(plot.canvasBackground().name())
+            self.background = str(plot.canvasBackground().color().name())
         self.maj_xenabled = grid.xEnabled()
         self.maj_yenabled = grid.yEnabled()
-        self.maj_line.update_param( grid.majPen() )
+        self.maj_line.update_param( grid.majorPen() )
         self.min_xenabled = grid.xMinEnabled()
         self.min_yenabled = grid.yMinEnabled()
-        self.min_line.update_param( grid.minPen() )
+        self.min_line.update_param( grid.minorPen() )
 
     def update_grid(self, grid):
         plot = grid.plot()
         if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
             plot.setCanvasBackground( QColor(self.background) )
         grid.enableX(self.maj_xenabled)
         grid.enableY(self.maj_yenabled)
         grid.setPen( self.maj_line.build_pen() )
         grid.enableXMin(self.min_xenabled)
         grid.enableYMin(self.min_yenabled)
-        grid.setMinPen( self.min_line.build_pen() )
+        grid.setMinorPen( self.min_line.build_pen() )
         grid.setTitle(self.get_title())
+        if plot is not None:
+            plot.blockSignals(False)
 
 
 # ===================================================
@@ -645,7 +652,7 @@ class AxesParam(DataSet):
 
     def update_axes(self, item):
         plot = item.plot()
-        plot.grid.setAxis(self.xaxis_id, self.yaxis_id)
+        plot.grid.setAxes(self.xaxis_id, self.yaxis_id)
         item.setXAxis(self.xaxis_id)
         self.xaxis.update_axis(plot, self.xaxis_id)
         item.setYAxis(self.yaxis_id)
@@ -863,21 +870,22 @@ class CurveParam(DataSet):
     line = LineStyleItem(_("Line"))
     symbol = SymbolItem(_("Symbol"))
     shade = FloatItem(_("Shadow"), default=0, min=0, max=1)
-    fitted = BoolItem(_("Fit curve to data"), _("Fitting"), default=False)
     curvestyle = ImageChoiceItem(_("Curve style"), CURVESTYLE_CHOICES,
                                  default="Lines")
-    curvetype = ImageChoiceItem(_("Curve type"), CURVETYPE_CHOICES,
-                                default="Yfx")
     baseline = FloatItem(_("Baseline"), default=0.)
 
     def update_param(self, curve):
+        self.label = to_text_string(curve.title().text())
         self.symbol.update_param(curve.symbol())
         self.line.update_param(curve.pen())
         self.curvestyle = CURVESTYLE_NAME[curve.style()]
-        self.curvetype = CURVETYPE_NAME[curve.curveType()]
         self.baseline = curve.baseline()
     
     def update_curve(self, curve):
+        plot = curve.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         if not self._multiselection:
             # Non common parameters
             curve.setTitle(self.label)
@@ -891,12 +899,11 @@ class CurveParam(DataSet):
         curve.setBrush(brush)
         # Symbol
         self.symbol.update_symbol( curve )
-        # CurveAttribute
-        curve.setCurveAttribute(QwtPlotCurve.Fitted, self.fitted)
         # Curve style, type and baseline
         curve.setStyle(getattr(QwtPlotCurve, self.curvestyle))
-        curve.setCurveType(getattr(QwtPlotCurve, self.curvetype))
         curve.setBaseline(self.baseline)
+        if plot is not None:
+            plot.blockSignals(False)
 
 class CurveParam_MS(CurveParam):
     _multiselection = True
@@ -922,7 +929,7 @@ class ErrorBarParam(DataSet):
     ontop = BoolItem(_("set to foreground"), _("Visibility"), default=False)
 
     def update_param(self, curve):
-        color = curve.errorPen.pen().color()
+        color = curve.errorPen.color()
         self.color = str(color.name())
         self.alpha = color.alphaF()
         self.width = curve.errorPen.widthF()
@@ -989,6 +996,10 @@ class BaseImageParam(DataSet):
             self.interpolation = size
 
     def update_image(self, image):
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.setTitle(self.label)
         image.set_color_map(self.colormap)
         size = self.interpolation
@@ -1000,6 +1011,8 @@ class BaseImageParam(DataSet):
         else:
             mode = INTERP_AA
         image.set_interpolation(mode, size)
+        if plot is not None:
+            plot.blockSignals(False)
 
 class QuadGridParam(DataSet):
     _multiselection = False
@@ -1039,11 +1052,17 @@ class QuadGridParam(DataSet):
         self.grid = image.grid
 
     def update_image(self, image):
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.setTitle(self.label)
         image.set_color_map(self.colormap)
         image.interpolate = (self.interpolation, self.uflat, self.vflat)
         image.grid = self.grid
         # TODO : gridcolor
+        if plot is not None:
+            plot.blockSignals(False)
 
 class RawImageParam(BaseImageParam):
     _hide_background = False
@@ -1057,7 +1076,13 @@ class RawImageParam(BaseImageParam):
 
     def update_image(self, image):
         super(RawImageParam, self).update_image(image)
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.set_background_color(self.background)
+        if plot is not None:
+            plot.blockSignals(False)
 
 class RawImageParam_MS(RawImageParam):
     _multiselection = True
@@ -1105,12 +1130,18 @@ class ImageParam(RawImageParam):
 
     def update_image(self, image):
         super(ImageParam, self).update_image(image)
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.xmin = self.xmin
         image.xmax = self.xmax
         image.ymin = self.ymin
         image.ymax = self.ymax
         image.update_bounds()
         image.update_border()
+        if plot is not None:
+            plot.blockSignals(False)
 
 class ImageParam_MS(ImageParam):
     _multiselection = True
@@ -1124,7 +1155,13 @@ class RGBImageParam(ImageParam):
 
     def update_image(self, image):
         super(RGBImageParam, self).update_image(image)
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.recompute_alpha_channel()
+        if plot is not None:
+            plot.blockSignals(False)
 
 class RGBImageParam_MS(RGBImageParam):
     _multiselection = True
@@ -1144,7 +1181,13 @@ class MaskedImageParam(ImageParam):
     
     def update_image(self, image):
         super(MaskedImageParam, self).update_image(image)
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.update_mask()
+        if plot is not None:
+            plot.blockSignals(False)
                          
 class MaskedImageParam_MS(MaskedImageParam):
     _multiselection = True
@@ -1217,7 +1260,13 @@ class TrImageParam(RawImageParam):
 
     def update_image(self, image):
         RawImageParam.update_image(self, image)
+        plot = image.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         image.set_transform(*self.get_transform())
+        if plot is not None:
+            plot.blockSignals(False)
 
     def get_transform(self):
         return (self.pos_x0, self.pos_y0, self.pos_angle*np.pi/180,
@@ -1368,9 +1417,11 @@ class MarkerParam(DataSet):
     def set_markerstyle(self, style):
         """
         Set marker line style
+
         style:
+            
             * convenient values: '+', '-', '|' or None
-            * QwtPlotMarker.NoLine, QwtPlotMarker.Vertical, ...
+            * `QwtPlotMarker.NoLine`, `QwtPlotMarker.Vertical`, ...
         """
         self.markerstyle = MARKERSTYLES.get(style, style)
 
@@ -1414,6 +1465,10 @@ class ShapeParam(DataSet):
         self.private = obj.is_private()
         
     def update_shape(self, obj):
+        plot = obj.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         obj.setTitle(self.label)
         obj.pen = self.line.build_pen()
         obj.symbol = self.symbol.build_symbol()
@@ -1423,6 +1478,8 @@ class ShapeParam(DataSet):
         obj.sel_brush = self.sel_fill.build_brush()
         obj.set_readonly(self.readonly)
         obj.set_private(self.private)
+        if plot is not None:
+            plot.blockSignals(False)
 
 class AxesShapeParam(DataSet):
     arrow_angle = FloatItem(_("Arrow angle (°)"), min=0, max=90, nonzero=True)
@@ -1485,12 +1542,18 @@ class AnnotationParam(DataSet):
         self.private = obj.is_private()
         
     def update_annotation(self, obj):
+        plot = obj.plot()
+        if plot is not None:
+            plot.blockSignals(True)  # Avoid unwanted calls of update_param 
+                                     # triggered by the setter methods below
         obj.setTitle(self.title)
         obj.set_label_visible(self.show_label)
         obj.area_computations_visible = self.show_computations
         obj.update_label()
         obj.set_readonly(self.readonly)
         obj.set_private(self.private)
+        if plot is not None:
+            plot.blockSignals(False)
 
 
 # ===================================================
