@@ -10,7 +10,6 @@
 SHOW = True # Show test in GUI-based test launcher
 
 from guidata.qt.QtGui import QWidget, QVBoxLayout, QHBoxLayout, QPushButton
-from guidata.qt.QtCore import SIGNAL
 
 #---Import plot widget base class
 from guiqwt.plot import CurveWidget
@@ -45,7 +44,7 @@ class FilterTestWidget(QWidget):
         #---
         
         button = QPushButton("Test filter: %s" % title)
-        self.connect(button, SIGNAL('clicked()'), self.process_data)
+        button.clicked.connect(self.process_data)
         vlayout = QVBoxLayout()
         vlayout.addWidget(curvewidget)
         vlayout.addWidget(button)
