@@ -7,11 +7,13 @@
 
 """Curve fitting tools"""
 
+from __future__ import print_function
+
 SHOW = True # Show test in GUI-based test launcher
 
 import numpy as np
 
-from guiqwt.fit import FitParam, guifit
+from guiqwt.widgets.fit import FitParam, guifit
 
 def test():
     x = np.linspace(-10, 10, 1000)
@@ -26,8 +28,8 @@ def test():
     params = [a, b]
     values = guifit(x, y, fit, params, xlabel="Time (s)", ylabel="Power (a.u.)")
     
-    print values
-    print [param.value for param in params]
+    print(values)
+    print([param.value for param in params])
 
 if __name__ == "__main__":
     test()
