@@ -9,8 +9,6 @@
 
 SHOW = True # Show test in GUI-based test launcher
 
-import numpy as np
-
 from guiqwt.plot import ImageDialog
 from guiqwt.builder import make
 import os.path as osp
@@ -20,9 +18,9 @@ SHOW = True # Show test in GUI-based test launcher
 TESTDIR = osp.abspath(osp.dirname(__file__))
 IMGFILE = osp.join(TESTDIR, "..", "images", "items", "image.png")
 
-def imshow( data ):
+def imshow(filename):
     win = ImageDialog(edit=False, toolbar=True, wintitle="RGB image item test")
-    item = make.rgbimage(data, xdata=[-1, 1], ydata=[-1, 1])
+    item = make.rgbimage(filename=filename, xdata=[-1, 1], ydata=[-1, 1])
     plot = win.get_plot()
     plot.add_item(item)
     win.show()
@@ -34,10 +32,7 @@ def test():
     import guidata
     _app = guidata.qapplication()
     # --
-    from PIL.Image import open
-    img = np.array(open(IMGFILE))
-    print img.shape
-    imshow(img)
+    imshow(IMGFILE)
 
 if __name__ == "__main__":
     test()
