@@ -1119,7 +1119,12 @@ class DockableTabWidget(QTabWidget, DockableWidgetMixin):
 
 
 try:
-    from spyderlib.widgets.internalshell import InternalShell
+    try:
+        # Spyder 2
+        from spyderlib.widgets.internalshell import InternalShell
+    except ImportError:
+        # Spyder 3
+        from spyder.widgets.internalshell import InternalShell
     class DockableConsole(InternalShell, DockableWidgetMixin):
         LOCATION = Qt.BottomDockWidgetArea
         def __init__(self, parent, namespace, message, commands=[]):
@@ -1135,7 +1140,11 @@ try:
             self.set_font(font)
             self.set_codecompletion_auto(True)
             self.set_calltips(True)
-            self.setup_completion(size=(300, 180), font=font)
+            try:
+                # Spyder 2
+                self.setup_completion(size=(300, 180), font=font)
+            except TypeError:
+                pass
             try:
                 self.traceback_available.connect(self.show_console)
             except AttributeError:
